<?PHP // $Id$ 
      // auth.php - created with Moodle 1.5 + (2005060201)


$string['alternatelogin'] = 'Pokud sem vlote njak URL, bude pouito jako pihlaovac strnka k tomuto systmu. Tato vae strnka by mla obsahovat formul s vlastnost \'action\' nastavenou na <strong>\'$a\'</strong>, kter vrac pole <strong>username</strong> a <strong>password</strong>.<br />Dbejte na to, abyste vloili platn URL! V opanm ppad byste mohli komukoliv vetn sebe zamezit pstupu k tmto strnkm.<br />Chcete-li pouvat standardn pihlaovac strnku, nechejte toto pole przdn.';
$string['alternateloginurl'] = 'URL vlastnho pihlen';
$string['auth_cas_baseuri'] = 'URI serveru (nebo nic, pokud nen baseUri)<br />Je-li nap. CAS server dostupn na  host.domena.cz/CAS/ pak nastavte<br />cas_baseuri = CAS/';
$string['auth_cas_create_user'] = 'Zapnte tuto volbu, chcete-li vkldat uivatele oven pomoc CAS do va databze uivatel Moodlu. V opanm ppad se budou moci pihlsit pouze uivatel, kte ji maj zznam v databzi Moodlu.';
$string['auth_cas_enabled'] = 'Zapnte tuto volbu, chcete-li pouvat CAS oven.';
$string['auth_cas_hostname'] = 'Nzev hostitele (hostname) serveru CAS<br />nap.: host.domena.cz';
$string['auth_cas_invalidcaslogin'] = 'Je mi lto, ale vae pihlen selhalo. Nebylo mono vs ovit';
$string['auth_cas_language'] = 'Vybran jazyk';
$string['auth_cas_logincas'] = 'Pstup po zaifrovanm spojen';
$string['auth_cas_port'] = 'Port CAS serveru';
$string['auth_cas_server_settings'] = 'Konfigurace CAS serveru';
$string['auth_cas_text'] = 'Zaifrovan spojen';
$string['auth_cas_version'] = 'Verze CAS';
$string['auth_casdescription'] = 'Tato metoda pouv pro oven uivatel server CAS (Central Authentication Service) v prosted Single Sign On (SSO). Mete rovn pout jednoduch LDAP ovovn. Je-li zadan uivatelsk jmno a heslo platn na serveru CAS, Moodle si vytvo nov zznam pro pslunho uivatele a ppadn nate dal atributy z LDAP serveru. Pi dalm pihlen se ji kontroluje pouze jmno a heslo.';
$string['auth_castitle'] = 'Pouvat CAS server (SSO)';
$string['auth_common_settings'] = 'Spolen nastaven';
$string['auth_data_mapping'] = 'Mapovn dat';
$string['auth_dbdescription'] = 'Tato metoda pouv tabulku v extern databzi ke kontrole, zda zadan uivatelsk jmno a heslo je platn.  Pi vytven novho tu mohou bt informace z dalch pol zkoprovny do databze Moodle.';
$string['auth_dbextrafields'] = 'Tato pole jsou voliteln. Mete si zvolit pednastaven nkterch informac o uivateli na zklad hodnot v <b>polch extern databze</b>, kter urte zde.<p>Nechte-li tato pole przdn, budou pouity implicitn hodnoty.<p>Tak jako tak si uivatel po pihlen me tato pole mnit.</p>';
$string['auth_dbfieldpass'] = 'Nzev pole, kter obsahuje hesla';
$string['auth_dbfielduser'] = 'Nzev pole, kter obsahuje uivatelsk jmna';
$string['auth_dbhost'] = 'Pota hostujc databzi';
$string['auth_dbname'] = 'Nzev databze';
$string['auth_dbpass'] = 'Heslo k tomuto uivatelskmu jmnu';
$string['auth_dbpasstype'] = 'Urete pouit formt pole s heslem. ifrovn MD5 je uiten pi pipojovn k dalm webovm aplikacm, jako je napklad PostNuke';
$string['auth_dbtable'] = 'Nzev tabulky v databzi';
$string['auth_dbtitle'] = 'Pouvat extern databzi';
$string['auth_dbtype'] = 'Typ databze (Viz <a href=\"../lib/adodb/readme.htm#drivers\">ADOdb dokumentaci</a>)';
$string['auth_dbuser'] = 'Uivatelsk jmno s prvy st extern databzi';
$string['auth_emaildescription'] = 'Potvrzen emailem je pednastaven metoda ovovn. Pi registraci si uivatel vybere vlastn uivatelsk jmno a heslo. Pot je na jeho adresu odesln email obsahujc zabezpeen odkaz na strnku, kde potvrd zadan daje. Pi dalm pihlen se ji ovuje pouze zadan uivatelsk jmno a heslo proti hodnot uloen v databzi Moodle.';
$string['auth_emailtitle'] = 'Oven na zklad emailu';
$string['auth_fccreators'] = 'Seznam skupin, jejich lenov jsou oprvnni vytvet nov kurzy. Skupiny oddlujte stednkem. Nzvy mus bt zadny pesn jako na FirstClass serveru a zle na malch/VELKCH psmenech.';
$string['auth_fcdescription'] = 'Tato metoda pouv k ovovan uivatelskho jmna a hesla FirstClass server.';
$string['auth_fcfppport'] = 'Port na serveru (nejbnj je 3333)';
$string['auth_fchost'] = 'Adresa serveru FirstClass. Vlote IP adresu nebo DNS nzev.';
$string['auth_fcpasswd'] = 'Heslo pro et uveden ve.';
$string['auth_fctitle'] = 'Pouvat FirstClass server';
$string['auth_fcuserid'] = 'Userid pro FirstClass et s nastavenm prvem \'Subadministrator\'';
$string['auth_fieldlock'] = 'Uzamknout hodnotu';
$string['auth_fieldlock_expl'] = '<p><b>Uzamknout hodnotu:</b> Je-li povoleno, zabrn se uivatelm i sprvcm mnit hodnotu pole pmo. Pouijte tuto volbu, pokud udrujete tyto daje v externm systmu.</p>';
$string['auth_fieldlocks'] = 'Uzamknout pole uivatel';
$string['auth_fieldlocks_help'] = '<p>Mte monost uzamknout pole s daji o uivatelch. To je uiten, pokud jako sprvce udrujete tyto daje run a/nebo nahrvnm daj pomoc funkce \'Nast uivatele\'. Pokud zamknete pole, kter Moodle vyaduje, ujistte se, e poskytujete potebn data pi vytven novch t &emdash; jinak budou ty nepouivateln.</p><p>Chcete-li pedejt tomuto problmu, zvate monost reimu \'Odemknuto, je-li pole przdn\'.</p>';
$string['auth_imapdescription'] = 'Tato metoda pouv server IMAP ke kontrole, zda je zadan uivatelsk jmno a heslo platn.';
$string['auth_imaphost'] = 'Adresa serveru IMAP. Zadejte IP adresu, nikoliv DNS jmno serveru!';
$string['auth_imapport'] = 'slo portu IMAP serveru. Vtinou bv 143 nebo 993.';
$string['auth_imaptitle'] = 'Pouvat IMAP server';
$string['auth_imaptype'] = 'Typ IMAP serveru. IMAP servery mohou mt rzn typy ovovn a vyjednvn (IMAP authentication and negotiation).';
$string['auth_ldap_bind_dn'] = 'Chcete-li pouvat njak et (bind-user) k vyhledn uivatel, specifikujte jej zde. Pklad: \'cn=ldapuser,ou=public,o=org\'';
$string['auth_ldap_bind_pw'] = 'Heslo pro bind-user';
$string['auth_ldap_bind_settings'] = 'Nastaven bind';
$string['auth_ldap_contexts'] = 'Seznam kontext, ve kterch se nachzej uivatel. Jednotliv kontexty oddlujte stednkem. Pklad: \'ou=uzivatele,o=naseskola; ou=dalsi,o=naseskola\'';
$string['auth_ldap_create_context'] = 'Povolte-li vytven uivatel (po oven emailem), urete kontext, ve kterm budou nov uivatel vytveni. Tento kontext by ml bt z bezpenostnch dvod odlin od kontextu ostatnch uivatel. Nen teba pidvat tento kontext do promnn auth_ldap_contexts, Moodle automaticky hled uivatele i v tomto kontextu.';
$string['auth_ldap_creators'] = 'Seznam skupin, jejich lenov jsou oprvnni vytvet nov kurzy. Jednotliv skupiny oddlujte stednkem. Pklad: \'cn=ucitele,ou=zamestnanci,o=naseskola\'';
$string['auth_ldap_expiration_desc'] = 'Zvolte Ne, chcete-li zakzat ovovn vyprelch hesel nebo ten \'passwordexpiration time\' pmo z LDAP';
$string['auth_ldap_expiration_warning_desc'] = 'Kolik dn ped vyprenm hesla zobrazovat varovn';
$string['auth_ldap_expireattr_desc'] = 'Voliteln: LDAP atribut, ve kterm je uloen as vypren hesla';
$string['auth_ldap_graceattr_desc'] = 'Voliteln: atribut \'gracelogin\'';
$string['auth_ldap_gracelogins_desc'] = 'Povolit podporu LDAP gracelogin (tzv. pihlen z milosti). I pot, co jim vyprelo heslo, se mohou uivatel pihlsit, dokud jim potadlo pihlen z milosti neklesne na 0. Uivatel jsou v ppad vypren hesla upozorovni.';
$string['auth_ldap_host_url'] = 'Zadejte URL serveru LDAP. Napklad \'ldap://ldap.naseskola.cz/\' nebo \'ldaps://ldap.naseskola.cz/\' ';
$string['auth_ldap_login_settings'] = 'Nastaven pihlen';
$string['auth_ldap_memberattribute'] = 'Voliteln: penastavuje nzev atributu lena skupiny (user member attribute), pokud uivatel pat do skupiny. Vtinou \'member\'';
$string['auth_ldap_objectclass'] = 'Voliteln: parametr objectClass pouit pi pojmenovvn/vyhledvn uivatel. Vtinou nemuste mnit.';
$string['auth_ldap_opt_deref'] = 'Uruje chovn alias bhem vyhledvn. Vyberte jednu z nsledujcch hodnot: \"Ne\" (LDAP_DEREF_NEVER) nebo \"Ano\" (LDAP_DEREF_ALWAYS)';
$string['auth_ldap_passwdexpire_settings'] = 'Nastaven vypren hesla LDAP';
$string['auth_ldap_search_sub'] = 'Prohledvat uivatele v subkontextech.';
$string['auth_ldap_server_settings'] = 'Nastaven serveru LDAP';
$string['auth_ldap_update_userinfo'] = 'Aktualizovat informace o uivateli (pjmen, kestn jmno, adresa...) z LDAP serveru do Moodle. Dle poteby definujte \'Mapovn dat\'.';
$string['auth_ldap_user_attribute'] = 'Voliteln: atribut pouit pro pojmenovn a vyhledvn uivatel. Vtinou \'cn\'.';
$string['auth_ldap_user_settings'] = 'Nastaven prohledvn uivatel';
$string['auth_ldap_user_type'] = 'Vyberte, jak jsou uivatel ukldni v LDAP. Toto nastaven zrove uruje, jak se bude chovat vypren hesla (login expiration), pihlen z milosti (grace logins) a tvorba uivatel.';
$string['auth_ldap_version'] = 'Verze protokolu LDAP, kterou pouv v server.';
$string['auth_ldapdescription'] = 'Tato metoda poskytuje oven uivatele proti LDAP serveru.  Je-li zadan jmno a heslo platn, Moodle si vytvo nov zznam o uivateli ve sv vlastn databzi. Tento modul um nast informace z LDAP serveru a pednastavit poadovan pole v Moodle. Pi dalm pihlaovn se ji pouze ovuje uivatelsk jmno a heslo.';
$string['auth_ldapextrafields'] = 'Tato pole jsou voliteln. Mete vybrat, kter pole s informacemi z <b>LDAP serveru</b> budou pouita jako pednastaven v Moodle. <p>Nechte-li pole przdn, nepevezmou se dn daje z LDAP a Moodle pouije vlastn pednastaven hodnoty. </p><p>V kadm ppad si uivatel me tyto hodnoty mnit po pihlen sm.</p>';
$string['auth_ldaptitle'] = 'Pouvat LDAP server';
$string['auth_manualdescription'] = 'Tato metoda neumouje uivatelm zakldat si vlastn ty. Vechny ty mus bt run vytvoeny sprvcem Moodle (admin).';
$string['auth_manualtitle'] = 'Pouze run vytven ty';
$string['auth_multiplehosts'] = 'Mete vloit i vce hostitel NEBO jejich adres (nap. \'server1.cz;server2.cz;server3.com\' nebo \'xxx.xxx.xxx.xxx;xxx.xxx.xxx.xxx\')';
$string['auth_nntpdescription'] = 'Tato metoda pouv NNTP server ke kontrole, zda je zadan uivatelsk jmno a heslo platn.';
$string['auth_nntphost'] = 'Adresa NNTP serveru. Zadejte IP adresu, nikoliv DNS nzev!';
$string['auth_nntpport'] = 'slo portu NNTP serveru (vtinou 119)';
$string['auth_nntptitle'] = 'Pouvat NNTP serveru';
$string['auth_nonedescription'] = 'Uivatel si mohou vytvet nov konta pmo bez oven vi externmu serveru nebo potvrzen pes email. S touto volbou bute opatrn - zvate mon problmy se zabezpeenm a sprvou uivatel, kter vm tato volba me zpsobit.';
$string['auth_nonetitle'] = 'Bez oven';
$string['auth_pamdescription'] = 'Tato metoda vyuv modul PAM pro pstup k nativnm uivatelskm jmnm na tomto serveru. Chcete-li tuto metodu pouvat, muste si nainstalovat <a href=\"http://www.math.ohio-state.edu/~ccunning/pam_auth/\" target=\"_blank\">PHP4 PAM Authentication</a>.';
$string['auth_pamtitle'] = 'PAM (Pluggable Authentication Modules)';
$string['auth_passwordisexpired'] = 'Vae heslo vyprelo. Chcete si jej te zmnit?';
$string['auth_passwordwillexpire'] = 'Poet dn do vypren hesla: $a. Chcete si sv heslo zmnit?';
$string['auth_pop3description'] = 'Tato metoda pouv POP3 server ke kontrole, zda zadan uivatelsk jmno a heslo je platn.';
$string['auth_pop3host'] = 'Adresa POP3 serveru. Zadejte IP adresu, nikoliv DNS nzev!';
$string['auth_pop3mailbox'] = 'Nzev potovn sloky (mailbox), se kterou se m navzat spojen (vtinou INBOX).';
$string['auth_pop3port'] = 'slo portu POP3 serveru (vtinou 110)';
$string['auth_pop3title'] = 'Pouvat POP3 server';
$string['auth_pop3type'] = 'Typ serveru. Pokud v server pouv zabezpeen pomoc certifikt, zvolte pop3cert.';
$string['auth_shib_convert_data'] = 'API pro pravu dat';
$string['auth_shib_convert_data_description'] = 'Toto API (aplikan rozhran) vm umouje dle upravovat data, kter mte k dispozici ze systmu Shibboleth. Vce infomac <a href=\"../auth/shibboleth/README.txt\" target=\"_blank\">zde</a>.';
$string['auth_shib_convert_data_warning'] = 'Soubor bu neexistuje, nebo k nmu nem proces webovho serveru pstup ke ten!';
$string['auth_shib_instructions'] = 'Pouijte <a href=\"$a\">pihlen se pes Shibboleth</a>, paklie vae instituce tento systm podporuje.<br />V opanm ppad pouijte normln formul pro pihlen.';
$string['auth_shib_instructions_help'] = 'Zde mete vloit vlastn informace o vaem systmu Shibboleth. Budou se zobrazovat na pihlaovac strnce. Vloen informace by mly obsahovat odkaz na zdroj chrnn systmem Shibboleth, kter pesmruje uivatele na \"<b>$a</b>\", take se uivatel systmu Shibboleth budou moci pihlsit do Moodlu. Nechte-li toto pole przdn, budou se na pihlaovac strnce zobrazovat obecn pokyny.';
$string['auth_shib_only'] = 'Pouze Shibboleth';
$string['auth_shib_only_description'] = 'Zakrtnte tuto volbu, chcete-li si vynutit pihlen pomoc systmu Shibboleth';
$string['auth_shib_username_description'] = 'Nzev promnn prosted webserveru Shibboleth, kter m bt pouita jako Moodlovsk uivatelsk jmno';
$string['auth_shibboleth_login'] = 'Pihlen pes Shibboleth';
$string['auth_shibboleth_manual_login'] = 'Run pihlen';
$string['auth_shibbolethdescription'] = 'Tato metoda umouje vytvet a ovovat uivatele pomoc systmu <a href=\"http://shibboleth.internet2.edu/\" target=\"_blank\">Shibboleth</a>.<br>Ujistte se, e jste si peetli soubor <a href=\"../auth/shibboleth/README.txt\" target=\"_blank\">README</a> obsahujc informace o tom, jak nastavit v Moodle pro podporu systmu Shibboleth.';
$string['auth_shibbolethtitle'] = 'Shibboleth';
$string['auth_updatelocal'] = 'Aktualizovat lokln data';
$string['auth_updatelocal_expl'] = '<p><b>Aktualizovat lokln data:</b> Je-li povoleno, budou pole aktualizovna (z externho autentizanho zdroje) po kadm pihlen nebo pi synchronizaci uivatel. Pole uren k mstn aktualizaci by mla bt uzamknuta.</p>';
$string['auth_updateremote'] = 'Aktualizovat extern data';
$string['auth_updateremote_expl'] = '<p><b>Aktualizovat extern data:</b> Je-li povoleno, provede se aktualizace externho autentizanho zdroje po kadm uloen profilu uivatele. Pole by mla bt odemknuta, aby je bylo mon upravovat.</p>';
$string['auth_updateremote_ldap'] = '<p><b>Pozn.:</b> Aktualizace externho zdroje LDAP vyaduje, aby ml uivatel \'binddn\' (s heslem \'bindpw\') oprvnn editovat vechny zznamy o uivatelch. Tento systm momentln nepodporuje atributy s vce hodnotami (multi-values) - extra hodnoty budou proto pi aktualizaci odstranny.</p>';
$string['auth_user_create'] = 'Povolit vytven uivatel';
$string['auth_user_creation'] = 'Nov (anonymn) uivatel si mohou zakldat uivatelsk et v externm zdroji a potvrdit jej pes email. Pokud toto povolte, nezapomete nakonfigurovat nastaven pro dan extern zdroj tkajc se vytven novch uivatel.';
$string['auth_usernameexists'] = 'Zvolen uivatelsk jmno ji existuje. Prosm, vyberte si jin.';
$string['authenticationoptions'] = 'Monosti oven';
$string['authinstructions'] = 'Zde mete zadat instrukce pro vae uivatele, aby vdli, kter uivatelsk jmno a heslo maj pout. Tento text se objev na pihlaovac strnce. Nechte-li toto pole przdn, nebudou zobrazeny dn instrukce.';
$string['changepassword'] = 'URL ke zmn hesla';
$string['changepasswordhelp'] = 'Zde mete urit URL, na kterm si vai uivatel mohou obnovit heslo nebo zmnit sv uivatelsk jmno, pokud jej zapomnli. URL bude uivatelm poskytnuto jako tlaitko na pihlaovac a osobn strnce. Nechte-li toto pole przdn, nebude toto tlatko zobrazovno.';
$string['chooseauthmethod'] = 'Vyberte si zpsob oven uivatel: ';
$string['createchangepassword'] = 'Vytvoit, pokud chyb - vnutit zmny';
$string['createpassword'] = 'Vytvoit, pokud chyb';
$string['forcechangepassword'] = 'Vynutit zmnu hesla';
$string['forcechangepassword_help'] = 'Vynutit zmnu hesla pi ptm pihlen do Moodlu.';
$string['forcechangepasswordfirst_help'] = 'Vynutit zmnu hesla pi prvnm pihlen do Moodlu.';
$string['guestloginbutton'] = 'Tlatko pro hosta';
$string['infilefield'] = 'Pole je v souboru poadovan';
$string['instructions'] = 'Pokyny';
$string['locked'] = 'Uzamknuto';
$string['md5'] = 'MD5 ifra';
$string['passwordhandling'] = 'Ukldat pole s heslem jako';
$string['plaintext'] = 'ist text';
$string['showguestlogin'] = 'Na pihlaovac strnce mete skrt nebo ukzat tlatko pro pihlen se jako host.';
$string['stdchangepassword'] = 'Pouij standardn strnku \'Zmna hesla\'';
$string['stdchangepassword_expl'] = 'Pokud v extern autentizan systm umouje zmnu hesla pes Moodle, pepnte na Ano. Tmto potlate hodnotu \'URL ke zmn hesla\'';
$string['stdchangepassword_explldap'] = 'Pozn.: Pokud pouvte vzdlen LDAP server, doporuujeme vm komunikovat pes ifrovan SSL spojen (ldaps://)';
$string['unlocked'] = 'Odemknuto';
$string['unlockedifempty'] = 'Odemknuto, je-li pole przdn';
$string['update_never'] = 'Nikdy';
$string['update_oncreate'] = 'Pi vytven';
$string['update_onlogin'] = 'Pi kadm pihlen';
$string['update_onupdate'] = 'Pi aktualizaci';

?>
